@@ -19,9 +19,12 @@
 
 package org.apache.tomcat.util.net.jss;
 
-import org.mozilla.jss.ssl.*;
-import org.apache.tomcat.util.net.*;
-import java.net.*;
+import java.net.Socket;
+
+import org.apache.tomcat.util.net.AbstractEndpoint;
+import org.apache.tomcat.util.net.SSLSupport;
+import org.apache.tomcat.util.net.ServerSocketFactory;
+import org.mozilla.jss.ssl.SSLSocket;
 
 class JSSFactory implements IJSSFactory {
     JSSFactory() {
@@ -32,6 +35,6 @@ class JSSFactory implements IJSSFactory {
     }
 
     public SSLSupport getSSLSupport(Socket socket) {
-        return new JSSSupport((SSLSocket)socket);
+        return new JSSSupport((SSLSocket) socket);
     }
 }
