@@ -20,21 +20,19 @@
 package org.apache.tomcat.util.net.jss;
 
 import java.net.Socket;
-import java.io.*;
+
 import org.apache.tomcat.util.net.AbstractEndpoint;
 import org.apache.tomcat.util.net.SSLImplementation;
 import org.apache.tomcat.util.net.SSLSupport;
 import org.apache.tomcat.util.net.SSLUtil;
 import org.apache.tomcat.util.net.ServerSocketFactory;
 
-public class JSSImplementation extends SSLImplementation
-{
-    static final String JSSFactory =
-      "org.apache.tomcat.util.net.jss.JSSFactory";
+public class JSSImplementation extends SSLImplementation {
+    static final String JSSFactory = "org.apache.tomcat.util.net.jss.JSSFactory";
     static final String SSLSocketClass = "org.mozilla.jss.ssl.SSLSocket";
 
-    static org.apache.commons.logging.Log logger =
-      org.apache.commons.logging.LogFactory.getLog(JSSImplementation.class);
+    static org.apache.commons.logging.Log logger = org.apache.commons.logging.LogFactory
+            .getLog(JSSImplementation.class);
 
     private JSSFactory factory = null;
 
@@ -43,9 +41,9 @@ public class JSSImplementation extends SSLImplementation
 
         try {
             Class factcl = Class.forName(JSSFactory);
-            factory = (JSSFactory)factcl.newInstance();
+            factory = (JSSFactory) factcl.newInstance();
         } catch (Exception e) {
-            if(logger.isDebugEnabled())
+            if (logger.isDebugEnabled())
                 logger.debug("Error getting factory: " + JSSFactory, e);
         }
     }
@@ -54,8 +52,7 @@ public class JSSImplementation extends SSLImplementation
         return "JSS";
     }
 
-    public ServerSocketFactory getServerSocketFactory(AbstractEndpoint endpoint)
-    {
+    public ServerSocketFactory getServerSocketFactory(AbstractEndpoint endpoint) {
         ServerSocketFactory ssf = factory.getSocketFactory(endpoint);
         return ssf;
     }
@@ -68,28 +65,28 @@ public class JSSImplementation extends SSLImplementation
 
     public SSLSupport getSSLSupport(javax.net.ssl.SSLSession session) {
         /*
-         * The Tomcat 6.0.26 docs says:
-         *     This method has been deprecated since it adds a JSSE dependency
-         *     to this interface. It will be removed in versions after 6.0.x.
-         *
+         * The Tomcat 6.0.26 docs says: This method has been deprecated since it
+         * adds a JSSE dependency to this interface. It will be removed in
+         * versions after 6.0.x.
+         * 
          * But we have to provide a implementation of this method because it's
          * declared as abstract.
-         *
+         * 
          * Unfortunately there does not appear to be any way to get SSLSupport
          * information from a session with JSS. JSS looks up the information
          * based on a socket, not a session. This done in SSLSocket.c
          * Java_org_mozilla_jss_ssl_SSLSocket_getStatus().
-         *
+         * 
          * So while it would be nice to provide a working implmentation there
          * doesn't seem to be an easy way to do this. Given that this method is
          * already deprecated and there hasn't been any evidence of it being
          * called it therefore seems reasonable to just return null to satify
          * the compiler's demand for an implementation.
-         *
+         * 
          * Once this abstract method is removed from SSLImplementation in a
          * future release we can remove this stub.
-         *
-         * NOTE:  This method has NOT yet been deprecated in Tomcat 7!
+         * 
+         * NOTE: This method has NOT yet been deprecated in Tomcat 7!
          */
         return null;
     }
